'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var experimentalUtils = require('@typescript-eslint/experimental-utils');
var prettier = _interopDefault(require('prettier'));
var path = _interopDefault(require('path'));

const createRule = experimentalUtils.ESLintUtils.RuleCreator(name => `${name}.md`);
const messages = {
  unformatted: "The content of this is not formatted"
};
const tags = {
  js: true,
  ts: true,
  tsx: true
};
const rules = {
  format: createRule({
    name: "format",
    defaultOptions: [],
    meta: {
      docs: {
        description: "Formats `js`, `ts` and `tsx` template tags with Prettier",
        recommended: "error"
      },
      messages,
      schema: [],
      type: "layout",
      fixable: "whitespace"
    },

    create(context) {
      return {
        TaggedTemplateExpression(node) {
          if (node.tag.type === "Identifier" && node.tag.name in tags && node.quasi.expressions.length === 0) {
            const str = node.quasi.quasis[0].value.cooked;
            const indentation = "".padEnd(node.tag.loc.start.column + 2);
            const lines = prettier.format(str, {
              filepath: path.join(path.dirname(context.getFilename()), `lint.${node.tag.name}`)
            }).split("\n");
            const formatted = "\n" + lines.map((line, i) => {
              if (i === lines.length - 1) {
                return "".padEnd(node.tag.loc.start.column) + line;
              }

              if (line === "") {
                return "";
              }

              return indentation + line;
            }).join("\n"); //+
            //   "\n" +
            //   "".padEnd(node.tag.loc.start.column);

            if (formatted !== str) {
              context.report({
                messageId: "unformatted",
                node: node.tag,

                fix(fixer) {
                  return fixer.replaceText(node.quasi, `\`${formatted}\``);
                }

              });
            }
          }
        }

      };
    }

  })
};

exports.rules = rules;
